@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2016  Friedrich W. H. Kossebau <kossebau@kde.org>
+// SPDX-FileCopyrightText: 2016 Friedrich W. H. Kossebau <kossebau@kde.org>
 
 #include "GeoUriRunner.h"
 
@@ -55,3 +50,5 @@ void GeoUriRunner::search(const QString &searchTerm, const GeoDataLatLonBox &)
 }
 
 }
+
+#include "moc_GeoUriRunner.cpp"
